# Copyright (c) 2000-2009, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%define with()          %{expand:%%{?with_%{1}:1}%%{!?with_%{1}:0}}
%define without()       %{expand:%%{?with_%{1}:0}%%{!?with_%{1}:1}}
%define bcond_with()    %{expand:%%{?_with_%{1}:%%global with_%{1} 1}}
%define bcond_without() %{expand:%%{!?_without_%{1}:%%global with_%{1} 1}}

%define _without_gcj_support 1

%bcond_without gcj_support
%bcond_without tests

%if %with gcj_support
%define gcj_support 1
%else
%define gcj_support 0
%endif

%define bname       geronimo
%define mstone      M2
%define section     free

# FIXME: an attempt was made to upgrade this package to 1.2.  Unfortunately,
#        this does not build in Fedora.  For starters, there are numerous
#        build dependencies that do not exist in Fedora.  For example,
#        mockobjects, jacorb, ws-scout, saxon-scripts, maven-release,
#        mojo-maven2-plugin-idlj.  Regressing to 1.1 is not an option as it
#        was never tagged nor built.  Thus, this package is being regressed
#        to 1.0-M2 level which was the last successful version built in
#        Fedora.  In the interest of maintainability, the large volume of
#        1.2 changes are being removed rather than commented out.  To
#        retrieve these changes and continue work on 1.2, check out the
#        spec file with tag: geronimo-specs-1_2-14_1_fc12.  The release
#        number is being set so there is an upgrade path from F-12 to
#        here.

Summary:        Geronimo J2EE server J2EE specifications
URL:            http://geronimo.apache.org
Source0:        %{bname}-%{version}-%{mstone}-src.tar.gz

Name:           geronimo-specs
Version:        1.0
Release:        3.2.M2%{?dist}
Epoch:          0
License:        ASL 2.0
Group:          Development/Libraries
BuildRequires:  jpackage-utils >= 0:1.5
BuildRequires:  mx4j >= 0:2.0.1
BuildRequires:  servletapi5
BuildRequires:  java-devel
Requires:       mx4j >= 0:2.0.1
Requires:       servletapi5
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-buildroot
%if %{gcj_support}
# libgcj aot-compiled native libraries
BuildRequires:  java-gcj-compat-devel >= 1.0.31
Requires(post): java-gcj-compat >= 1.0.31
Requires(postun):java-gcj-compat >= 1.0.31
%else
BuildArch:      noarch
%endif

%description
Geronimo is Apache's ASF-licenced J2EE server project.
These are the J2EE-Specifications

%package compat
Group:          Development/Libraries
Summary:        Compatibility package for %{name}
Requires:       %{name} = %{version}-%{release}
Provides:       ejb = 0:2.1
Provides:       j2ee-connector = 0:1.5
Provides:       j2ee-deployment = 0:1.1
Provides:       j2ee-management = 0:1.0
Provides:       jacc = 0:1.0
Provides:       jms = 0:1.1
Provides:       jta = 0:1.0.1

%description compat
Fedora-specific package to make %{name} look like the
individual JPackages of the specifications we provide.

%prep
%setup -q -n geronimo-%{version}-%{mstone}
chmod -R go=u-w *

%build
# Force Java 5 (GCJ) as this code will not build on Java 6
# due to API differences (-source and -target only solve syntax problems)
export JAVA_HOME=/usr/lib/jvm/java-1.5.0
export PATH=$JAVA_HOME/bin:$PATH

mkdir -p build/lib
for spec in \
  ejb-2.1 \
  j2ee-connector-1.5 \
  j2ee-deployment-1.1 \
  j2ee-jacc-1.0 \
  j2ee-management-1.0 \
  jms-1.1 \
  jta-1.0.1B; do
    name=`echo $spec | sed 's:-[^-]*$::'`
    srcdir=specs/$name/src/java
    classdir=build/classes/$name
    mkdir -p $classdir
    jarfile=build/lib/spec-$spec.jar
    case $name in
    j2ee-jacc)
        CLASSPATH=$(build-classpath servletapi5)
        export CLASSPATH
        ;;
    j2ee-management)
        CLASSPATH=$(build-classpath mx4j/mx4j-jmx):build/lib/spec-ejb-2.1.jar
        export CLASSPATH
        ;;
    *)
        unset CLASSPATH
    esac

    find $srcdir -name '*.java' | xargs javac  \
                -source 1.4 -target 1.4 -d $classdir || exit 1
    mkdir -p $classdir/META-INF
    cp -a LICENSE.txt $classdir/META-INF
    jar cf $jarfile -C $classdir .
done

%install
rm -rf $RPM_BUILD_ROOT

install -d -m 0755 $RPM_BUILD_ROOT%{_javadir}/%{bname}
for jar in build/lib/*.jar; do
    base=`basename $jar .jar`
    install -m 0644 $jar $RPM_BUILD_ROOT%{_javadir}/%{bname}/$base-rc2.jar
    ln -s $base-rc2.jar $RPM_BUILD_ROOT%{_javadir}/%{bname}/$base.jar

    compat=`echo $base | sed 's:^spec-\(.*\)-[^-]*$:\1:'`
    [ $compat = j2ee-jacc ] && compat=jacc
    ln -s %{bname}/$base.jar $RPM_BUILD_ROOT%{_javadir}/$compat.jar
done

%if %{gcj_support}
aot-compile-rpm
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%post
%if %{gcj_support}
%{_bindir}/rebuild-gcj-db
%endif

%postun
%if %{gcj_support}
%{_bindir}/rebuild-gcj-db
%endif

%files
%defattr(-,root,root,-)
%doc LICENSE.txt NOTICE.txt
%{_javadir}/%{bname}
%if %{gcj_support}
%attr(-,root,root) %{_libdir}/gcj/%{name}
%endif

%files compat
%defattr(-,root,root,-)
%{_javadir}/*.jar

%changelog
* Wed Jan 20 2010 Jeff Johnston <jjohnstn@redhat.com> - 0:1.0-3.2.M2
- Resolves: #511494
- Regress to 1.0-M2 until 1.2 build requirements are satisfied and build
  is successful.
- Switch to noarch by default.

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0:1.2-14.1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Fri Mar 20 2009 David Walluck <dwalluck@redhat.com> 0:1.2-13.1
- enable tests
- correctly define gcj_support
- add BuildConflicts: geronimo-specs
- add missing maven2-2.0.8 BuildRequires
- add patch for versions
- correctly define versions
- use %%{jar} macro

* Fri Mar 20 2009 Ralph Apel <r.apel@r-apel.de> 0:1.2-13
- Give the alternatives provided by -j2ee-1.4-apis a very low prio
- Fix creation of -j2ee-1.4-apis jar file
- Omit excessive (conflicting) Obsoletes

* Wed Mar 11 2009 Ralph Apel <r.apel@r-apel.de> 0:1.2-12
- Drop BR itself

* Fri Oct 10 2008 David Walluck <dwalluck@redhat.com> 0:1.2-11
- change Conflicts: geronimo-specs-compat to Obsoletes

* Mon Sep 22 2008 David Walluck <dwalluck@redhat.com> 0:1.2-10
- add Conflicts: geronimo-specs-compat

* Mon Sep 22 2008 David Walluck <dwalluck@redhat.com> 0:1.2-9
- fix build
- add avalon-framework to maven depmap

* Mon Sep 08 2008 David Walluck <dwalluck@redhat.com> 0:1.2-8
- fix build under JDK6

* Thu Aug 07 2008 David Walluck <dwalluck@redhat.com> 0:1.2-7
- geronimo-j2ee-1.4-apis should have j2ee-conenctor alternative

* Thu Aug 07 2008 Ralph Apel <r.apel at r-apel.de> - 0:1.2-6.jpp5
- Fix geronimo-j2ee-1.4-apis jar file (maven2-plugin-assembly usage)
- BR jacorb >= 0:2.3.0-11

* Wed Jul 16 2008 David Walluck <dwalluck@redhat.com> 0:1.2-5
- remove excalibur/avalon-logkit from CLASSPATH

* Thu Jul 10 2008 David Walluck <dwalluck@redhat.com> 0:1.2-4
- conditionalize tests

* Thu Jul 10 2008 David Walluck <dwalluck@redhat.com> 0:1.2-3
- use %%{_sbindir} macro
- fix GCJ support
- fix poms directory ownership
- remove spurious gnu-crypto dependency
- use more strict permissions
- update License
- update BuildRoot
- update Release
- remove Vendor and Distribution

* Fri Nov 09 2007 Ralph Apel <r.apel at r-apel.de> - 0:1.2-2jpp
- Reenter legacy provides (without _): should be dropped asap
- Introduced dependencies between apis

* Tue Oct 23 2007 Ralph Apel <r.apel at r-apel.de> - 0:1.2-1jpp
- Upgrade to 1.2 (extended)
- Rename virtual capabilities
- Commented out the triggers for now

* Thu May 31 2007 Ralph Apel <r.apel at r-apel.de> - 0:1.1-4jpp
- Fix aot build
- Drop false Requires: wsdl4j for -qname-1.1-api
- Create alternative for qname.jar

* Sun Feb 25 2007 Deepak Bhole <dbhole@redhat.com> - 0:1.1-3jpp
- Rebuilding

* Mon Feb 19 2007 Deepak Bhole <dbhole@redhat.com> - 0:1.1-2jpp
- Update for new maven2

* Mon Sep 25 2006 Ralph Apel <r.apel@r-apel.de> 0:1.1-1jpp
- Upgrade to 1.1
- Add post/postun Requires for javadoc
- Add gcj_support option
- Now build with maven2
- Add corba, corba-3.0 subpackages
- Add commonj subpackage
- geronimo-jaf-1.0.2-api should not obsolete jaf, as this is
  also provided by classpathx-jaf: TODO: we need a conflict free
  specs naming scheme
- build geronimo-spec-j2ee separately: no javadoc:javadoc to build

* Tue Mar 07 2006 Fernando Nasser <fnasser@redhat.com> 0:1.0-3jpp
- Patch JACC to fix EJBMethodPermission wrong signature problem

* Tue Feb 14 2006 Ralph Apel <r.apel@r-apel.de> 0:1.0-2jpp
- Revert renaming of geronimo-jacc to geronimo-j2ee-jacc

* Mon Feb 13 2006 Ralph Apel <r.apel@r-apel.de> 0:1.0-1jpp
- Upgrade to 1.0 final
- Renamed geronimo-jacc to geronimo-j2ee-jacc
- Generate most of project.xml files by xsl

* Thu Dec 22 2005 Fernando Nasser <fnasser@redhat.com> 0:1.0-0.M4.1jpp
- First JPP 1.7 build
- Add missing build dependency on maven-plugin-multiproject

* Fri Dec 02 2005 Fernando Nasser <fnasser@redhat.com> 0:1.0-0.M4.1jpp_10rh
- Require update-alternatives in the subpackages that actually use it.

* Mon Nov 21 2005 Fernando Nasser <fnasser@redhat.com> 0:1.0-0.M4.1jpp_9rh
- Do not add/remove javamail alternatives either.

* Thu Nov 17 2005 Fernando Nasser <fnasser@redhat.com> 0:1.0-0.M4.1jpp_8rh
- Do not provide 'javamail' as this is just the API (is it?) and
  our 'javamail' alternative means the providers as well
  all in a single jar file called 'javamail.jar'

* Tue Nov 15 2005 Fernando Nasser <fnasser@redhat.com> 0:1.0-0.M4.1jpp_7rh
- Handle replacement of jaf alternative
- Remove leading zeroes from alternative priorities

* Tue Nov 08 2005 Fernando Nasser <fnasser@redhat.com> 0:1.0-0.M4.1jpp_6rh
- New 6-digit JPP alternative priorities
- Main package has links and requires subpackages

* Wed Nov 02 2005 Fernando Nasser <fnasser@redhat.com> 0:1.0-0.M4.1jpp_5rh
- Add Obsoletes to non-free packages and add versions to Provides
- Remove file from old non-free packages using a trigger
- Remove alternatives in preun instead of postun
- Require update-alternatives in preun and post
- Own alternatives links by ghost

* Sat Oct 22 2005 Fernando Nasser <fnasser@redhat.com> 0:1.0-0.M4.1jpp_4rh
- Add dash to j2ee-schema jar and link names

* Sat Oct 22 2005 Fernando Nasser <fnasser@redhat.com> 0:1.0-0.M4.1jpp_3rh
- Fix broken link to j2ee-schema jar

* Mon Aug 15 2005 Deepak Bhole <dbhole@redhat.com> 0:1.0-0.M4.1jpp_2rh
- Update dependencies
- Remove code to build repository; depmap handles this now

* Tue Aug 09 2005 Fernando Nasser <fnasser@redhat.com> 0:1.0-0.M4.1jpp_1rh
- Merge with upstream

* Tue Aug 09 2005 Fernando Nasser <fnasser@redhat.com> 0:1.0-0.M4.1jpp
- Upgrade to M4

* Tue Aug 09 2005 Fernando Nasser <fnasser@redhat.com> 0:1.0-0.M2.3jpp_1rh
- Merge with upstream

* Thu Jun 01 2005 Fernando Nasser <fnasser@redhat.com> 0:1.0-0.M2.3jpp
- Add missing dependency on isorelax
- Set JAVA_HOME
- Rename pom files to prevent conflict with similar files from other packages

* Thu Apr 28 2005 Fernando Nasser <fnasser@redhat.com> 0:1.0-0.M2.2jpp_1rh
- First Red Hat build
- Add missing build requires for jakarta-commons-jelly-tags-xml and forehead
- Add missing build requires for maven-plugins-base
- Use unversioned maven directory and require version >= 1.0.2

* Thu Feb 03 2005 Ralph Apel <r.apel at r-apel.de> 0:1.0-0.M2.2jpp
- Process project.xml files with saxon
- Don't tamper with $HOME
- Don't use build-jar-repository: [xyz].jar will not work with geronimo deploy

* Fri Oct 08 2004 Ralph Apel <r.apel at r-apel.de> 0:1.0-0.M2.1jpp
- Upgrade to M2
* Thu Sep 30 2004 Ralph Apel <r.apel at r-apel.de> 0:1.0-0.M1.1jpp
- First JPackage build

